from eeggan.Train_Gan import train_gan
from eeggan.Visualize_Gan import visualize_gan
from eeggan.Generate_Samples import generate_samples
from eeggan.Setup_Tutorial import setup_tutorial